@@ -1,16 +1,14 @@
-use std::collections::{BTreeMap, BTreeSet};
+use std::{
+    collections::{BTreeMap, BTreeSet},
+    hash::{Hash, Hasher},
+    path::PathBuf,
+};
 
 use miette::Diagnostic;
-use pixi_build_discovery::EnabledProtocols;
-use pixi_build_frontend::{
-    Backend,
-    types::{
-        ChannelConfiguration, PlatformAndVirtualPackages,
-        procedures::conda_metadata::CondaMetadataParams,
-    },
-};
-use pixi_build_type_conversions::compute_project_model_hash;
-use pixi_build_types::procedures::conda_outputs::CondaOutputsParams;
+use pathdiff::diff_paths;
+use pixi_build_discovery::{CommandSpec, EnabledProtocols};
+use pixi_build_frontend::Backend;
+use pixi_build_types::{ProjectModelV1, procedures::conda_outputs::CondaOutputsParams};
 use pixi_glob::GlobHashKey;
 use pixi_record::{InputHash, PinnedSourceSpec};
 use pixi_spec::{SourceAnchor, SourceSpec};
@@ -18,6 +16,7 @@ use rand::random;
 use rattler_conda_types::{ChannelConfig, ChannelUrl};
 use thiserror::Error;
 use tracing::instrument;
+use xxhash_rust::xxh3::Xxh3;
 
 use crate::{
     BuildEnvironment, CommandDispatcher, CommandDispatcherError, CommandDispatcherErrorResultExt,
@@ -27,6 +26,8 @@ use crate::{
         source_metadata_cache::{self, CachedCondaMetadata, MetadataKind, SourceMetadataKey},
     },
 };
+use pixi_build_discovery::BackendSpec;
+use pixi_build_frontend::BackendOverride;
 
 /// Represents a request for metadata from a build backend for a particular
 /// source location. The result of this request is the metadata for that
@@ -49,6 +50,9 @@ pub struct BuildBackendMetadataSpec {
     /// Variant configuration
     pub variants: Option<BTreeMap<String, Vec<String>>>,
 
+    /// Variant file paths provided by the workspace.
+    pub variant_files: Option<Vec<PathBuf>>,
+
     /// The protocols that are enabled for this source
     #[serde(skip_serializing_if = "crate::is_default")]
     pub enabled_protocols: EnabledProtocols,
@@ -101,11 +105,16 @@ impl BuildBackendMetadataSpec {
             .map_err_with(BuildBackendMetadataError::Discovery)?;
 
         // Calculate the hash of the project model
-        let project_model_hash = discovered_backend
-            .init_params
-            .project_model
-            .as_ref()
-            .map(compute_project_model_hash);
+        let additional_glob_hash = calculate_additional_glob_hash(
+            &discovered_backend.init_params.project_model,
+            &self.variants,
+        );
+
+        // Check if we should skip the metadata cache for this backend
+        let skip_cache = Self::should_skip_metadata_cache(
+            &discovered_backend.backend_spec,
+            command_dispatcher.build_backend_overrides(),
+        );
 
         // Check the source metadata cache, short circuit if there is a cache hit that
         // is still fresh.
@@ -116,19 +125,30 @@ impl BuildBackendMetadataSpec {
             .await
             .map_err(BuildBackendMetadataError::Cache)
             .map_err(CommandDispatcherError::Failed)?;
-        if let Some(metadata) = Self::verify_cache_freshness(
-            &source_checkout,
-            &command_dispatcher,
-            metadata,
-            &project_model_hash,
-        )
-        .await?
-        {
-            return Ok(BuildBackendMetadata {
+
+        if !skip_cache {
+            if let Some(metadata) = Self::verify_cache_freshness(
+                &source_checkout,
+                &command_dispatcher,
                 metadata,
-                cache_entry,
-                source: source_checkout.pinned,
-            });
+                &additional_glob_hash,
+            )
+            .await?
+            {
+                return Ok(BuildBackendMetadata {
+                    metadata,
+                    cache_entry,
+                    source: source_checkout.pinned,
+                });
+            }
+        } else {
+            let backend_name = match &discovered_backend.backend_spec {
+                BackendSpec::JsonRpc(spec) => &spec.name,
+            };
+            tracing::warn!(
+                "metadata cache disabled for build backend '{}' (system/path-based backends always regenerate metadata)",
+                backend_name
+            );
         }
 
         // Instantiate the backend with the discovered information.
@@ -145,40 +165,28 @@ impl BuildBackendMetadataSpec {
             .await
             .map_err_with(BuildBackendMetadataError::Initialize)?;
 
-        // Based on the version of the backend, call the appropriate method to get
-        // metadata.
+        // Call the conda_outputs method to get metadata.
         let source = source_checkout.pinned.clone();
-        let metadata = if backend.capabilities().provides_conda_outputs() {
-            tracing::trace!(
-                "Using `{}` procedure to get metadata information",
-                pixi_build_types::procedures::conda_outputs::METHOD_NAME
-            );
-            self.call_conda_outputs(
-                command_dispatcher,
-                source_checkout,
-                backend,
-                project_model_hash,
-            )
-            .await?
-        } else if backend.capabilities().provides_conda_metadata() {
-            tracing::trace!(
-                "Using `{}` procedure to get metadata information",
-                pixi_build_types::procedures::conda_metadata::METHOD_NAME
-            );
-            self.call_conda_get_metadata(
-                command_dispatcher,
-                source_checkout,
-                backend,
-                project_model_hash,
-            )
-            .await?
-        } else {
+        if !backend.capabilities().provides_conda_outputs() {
             return Err(CommandDispatcherError::Failed(
                 BuildBackendMetadataError::BackendMissingCapabilities(
                     backend.identifier().to_string(),
                 ),
             ));
-        };
+        }
+
+        tracing::trace!(
+            "Using `{}` procedure to get metadata information",
+            pixi_build_types::procedures::conda_outputs::METHOD_NAME
+        );
+        let metadata = self
+            .call_conda_outputs(
+                command_dispatcher,
+                source_checkout,
+                backend,
+                additional_glob_hash,
+            )
+            .await?;
 
         // Store the metadata in the cache for later retrieval
         cache_entry
@@ -194,11 +202,41 @@ impl BuildBackendMetadataSpec {
         })
     }
 
+    /// Checks if we should skip the metadata cache for this backend.
+    /// Returns true if:
+    /// 1. There's a System backend override (either for this specific backend or all backends)
+    /// 2. OR the original backend spec is System or mutable (path-based non-binary)
+    fn should_skip_metadata_cache(
+        backend_spec: &BackendSpec,
+        backend_override: &BackendOverride,
+    ) -> bool {
+        let BackendSpec::JsonRpc(json_rpc_spec) = backend_spec;
+
+        // Check if there's a System backend override for this backend
+        // In-memory overrides are deterministic and can use cached metadata
+        let has_system_override = match backend_override {
+            BackendOverride::System(overridden_backends) => overridden_backends
+                .named_backend_override(&json_rpc_spec.name)
+                .is_some(),
+            BackendOverride::InMemory(_) => false,
+        };
+
+        if has_system_override {
+            return true;
+        }
+
+        // Check if the original backend spec is System or mutable
+        match &json_rpc_spec.command {
+            CommandSpec::System(_) => true,
+            CommandSpec::EnvironmentSpec(env_spec) => env_spec.requirement.1.is_mutable(),
+        }
+    }
+
     async fn verify_cache_freshness(
         source_checkout: &SourceCheckout,
         command_dispatcher: &CommandDispatcher,
         metadata: Option<CachedCondaMetadata>,
-        project_model_hash: &Option<Vec<u8>>,
+        additional_glob_hash: &[u8],
     ) -> Result<Option<CachedCondaMetadata>, CommandDispatcherError<BuildBackendMetadataError>>
     {
         let Some(metadata) = metadata else {
@@ -206,9 +244,7 @@ impl BuildBackendMetadataSpec {
         };
 
         let metadata_kind = match metadata.metadata {
-            MetadataKind::GetMetadata { .. } => {
-                pixi_build_types::procedures::conda_metadata::METHOD_NAME
-            }
+            MetadataKind::GetMetadata { .. } => "conda/getMetadata",
             MetadataKind::Outputs { .. } => {
                 pixi_build_types::procedures::conda_outputs::METHOD_NAME
             }
@@ -226,7 +262,7 @@ impl BuildBackendMetadataSpec {
             .compute_hash(GlobHashKey::new(
                 source_checkout.path.clone(),
                 input_globs.globs.clone(),
-                project_model_hash.clone(),
+                additional_glob_hash.to_vec(),
             ))
             .await
             .map_err(BuildBackendMetadataError::GlobHash)
@@ -248,13 +284,14 @@ impl BuildBackendMetadataSpec {
         command_dispatcher: CommandDispatcher,
         source_checkout: SourceCheckout,
         backend: Backend,
-        project_model_hash: Option<Vec<u8>>,
+        additional_glob_hash: Vec<u8>,
     ) -> Result<CachedCondaMetadata, CommandDispatcherError<BuildBackendMetadataError>> {
         let params = CondaOutputsParams {
             channels: self.channels,
             host_platform: self.build_environment.host_platform,
             build_platform: self.build_environment.build_platform,
-            variant_configuration: self.variants.map(|variants| variants.into_iter().collect()),
+            variant_configuration: self.variants.clone(),
+            variant_files: self.variant_files.clone(),
             work_directory: command_dispatcher.cache_dirs().working_dirs().join(
                 WorkDirKey {
                     source: SourceRecordOrCheckout::Checkout {
@@ -273,11 +310,16 @@ impl BuildBackendMetadataSpec {
             .map_err(CommandDispatcherError::Failed)?;
 
         // Compute the input globs for the mutable source checkouts.
+        let input_globs = extend_input_globs_with_variant_files(
+            outputs.input_globs.clone(),
+            &self.variant_files,
+            &source_checkout,
+        );
         let input_hash = Self::compute_input_hash(
             command_dispatcher,
             &source_checkout,
-            outputs.input_globs.clone(),
-            project_model_hash,
+            input_globs,
+            additional_glob_hash,
         )
         .await?;
 
@@ -290,70 +332,12 @@ impl BuildBackendMetadataSpec {
         })
     }
 
-    /// Use the `conda/getMetadata` procedure to get the metadata for the source
-    async fn call_conda_get_metadata(
-        self,
-        command_dispatcher: CommandDispatcher,
-        source_checkout: SourceCheckout,
-        backend: Backend,
-        project_model_hash: Option<Vec<u8>>,
-    ) -> Result<CachedCondaMetadata, CommandDispatcherError<BuildBackendMetadataError>> {
-        // Query the backend for metadata.
-        let params = CondaMetadataParams {
-            build_platform: Some(PlatformAndVirtualPackages {
-                platform: self.build_environment.build_platform,
-                virtual_packages: Some(self.build_environment.build_virtual_packages),
-            }),
-            host_platform: Some(PlatformAndVirtualPackages {
-                platform: self.build_environment.host_platform,
-                virtual_packages: Some(self.build_environment.host_virtual_packages),
-            }),
-            channel_base_urls: Some(self.channels.into_iter().map(Into::into).collect()),
-            channel_configuration: ChannelConfiguration {
-                base_url: self.channel_config.channel_alias.clone(),
-            },
-            variant_configuration: self.variants.map(|variants| variants.into_iter().collect()),
-            work_directory: command_dispatcher.cache_dirs().working_dirs().join(
-                WorkDirKey {
-                    source: SourceRecordOrCheckout::Checkout {
-                        checkout: source_checkout.clone(),
-                    },
-                    host_platform: self.build_environment.host_platform,
-                    build_backend: backend.identifier().to_string(),
-                }
-                .key(),
-            ),
-        };
-        let metadata = backend
-            .conda_get_metadata(params)
-            .await
-            .map_err(BuildBackendMetadataError::Communication)
-            .map_err(CommandDispatcherError::Failed)?;
-
-        // Compute the input globs for the mutable source checkouts.
-        let input_hash = Self::compute_input_hash(
-            command_dispatcher,
-            &source_checkout,
-            metadata.input_globs.clone().unwrap_or_default(),
-            project_model_hash,
-        )
-        .await?;
-
-        Ok(CachedCondaMetadata {
-            id: random(),
-            input_hash: input_hash.clone(),
-            metadata: MetadataKind::GetMetadata {
-                packages: metadata.packages,
-            },
-        })
-    }
-
     /// Computes the input hash for metadata returned by the backend.
     async fn compute_input_hash(
         command_queue: CommandDispatcher,
         source: &SourceCheckout,
         input_globs: BTreeSet<String>,
-        project_model_hash: Option<Vec<u8>>,
+        additional_glob_hash: Vec<u8>,
     ) -> Result<Option<InputHash>, CommandDispatcherError<BuildBackendMetadataError>> {
         if source.pinned.is_immutable() {
             // If the source is immutable (e.g., a git commit), we do not need to compute an
@@ -367,7 +351,7 @@ impl BuildBackendMetadataSpec {
             .compute_hash(GlobHashKey::new(
                 &source.path,
                 input_globs.clone(),
-                project_model_hash,
+                additional_glob_hash,
             ))
             .await
             .map_err(BuildBackendMetadataError::GlobHash)
@@ -391,6 +375,28 @@ impl BuildBackendMetadataSpec {
     }
 }
 
+/// Returns the input glob set extended with any variant file paths
+/// relative to the source checkout root.
+/// Paths are normalised to use forward slashes so that they are glob-compatible.
+fn extend_input_globs_with_variant_files(
+    mut input_globs: BTreeSet<String>,
+    variant_files: &Option<Vec<PathBuf>>,
+    source_checkout: &SourceCheckout,
+) -> BTreeSet<String> {
+    if let Some(variant_files) = variant_files {
+        for variant_file in variant_files {
+            let relative = match variant_file.strip_prefix(&source_checkout.path) {
+                Ok(stripped) => stripped.to_path_buf(),
+                Err(_) => diff_paths(variant_file, &source_checkout.path)
+                    .unwrap_or_else(|| variant_file.clone()),
+            };
+            let glob = relative.to_string_lossy().replace("\\", "/");
+            input_globs.insert(glob);
+        }
+    }
+    input_globs
+}
+
 #[derive(Debug, Error, Diagnostic)]
 pub enum BuildBackendMetadataError {
     #[error(transparent)]
@@ -412,9 +418,7 @@ pub enum BuildBackendMetadataError {
     #[diagnostic(transparent)]
     Communication(#[from] pixi_build_frontend::json_rpc::CommunicationError),
 
-    #[error(
-        "the build backend {0} does not support either the `conda/outputs` or `conda/getMetadata` procedures"
-    )]
+    #[error("the build backend {0} does not support the `conda/outputs` procedure")]
     BackendMissingCapabilities(String),
 
     #[error("could not compute hash of input files")]
@@ -423,3 +427,20 @@ pub enum BuildBackendMetadataError {
     #[error(transparent)]
     Cache(#[from] source_metadata_cache::SourceMetadataCacheError),
 }
+
+/// Computes an additional hash to be used in glob hash
+pub fn calculate_additional_glob_hash(
+    project_model: &Option<ProjectModelV1>,
+    variants: &Option<BTreeMap<String, Vec<String>>>,
+) -> Vec<u8> {
+    let mut hasher = Xxh3::new();
+    if let Some(project_model) = project_model {
+        project_model.hash(&mut hasher);
+    }
+    if let Some(variants) = variants {
+        if !variants.is_empty() {
+            variants.hash(&mut hasher);
+        }
+    }
+    hasher.finish().to_ne_bytes().to_vec()
+}
